==> ejc-technologymanage-impl-3.0.0-20221228.061103-23-sources.jar: com/ejianc/business/constructor/bean/YearTechnologyIndexPlanEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.constructor.bean.YearTechnologyIndexPlanZiEntity;
/**
 * 年度科技指标计划
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_year_technology_index_plan")
public class YearTechnologyIndexPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="year")
    private Date year; // 年份
    @TableField(value="department_id")
    private Long departmentId; // 单位
    @TableField(value="department_name")
    private String departmentName; // 单位名称
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="yearTechnologyIndexPlanZiService",pidName = "zhuId")
    private List<YearTechnologyIndexPlanZiEntity> yearTechnologyIndexPlanZiList = new ArrayList<>(); // 年度科技指标计划子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public Date getYear() {
        return year;
    }

    public void setYear(Date year) {
        this.year = year;
    }
    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    

    public List<YearTechnologyIndexPlanZiEntity> getYearTechnologyIndexPlanZiList() {
        return yearTechnologyIndexPlanZiList;
    }

    public void setYearTechnologyIndexPlanZiList(List<YearTechnologyIndexPlanZiEntity> yearTechnologyIndexPlanZiList) {
        this.yearTechnologyIndexPlanZiList = yearTechnologyIndexPlanZiList;
    }
}

==> ejc-technologymanage-impl-3.0.0-20251009.061228-54-sources.jar: com/ejianc/business/constructor/bean/YearTechnologyIndexPlanEntity.java <==
package com.ejianc.business.constructor.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.constructor.bean.YearTechnologyIndexPlanZiEntity;
/**
 * 年度科技指标计划
 * 
 * @author generator
 * 
 */
 @TableName("t_technologymanage_year_technology_index_plan")
public class YearTechnologyIndexPlanEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="project_id")
    private Long projectId; // 项目
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="year")
    private String year; // 年份
    @TableField(value="department_id")
    private Long departmentId; // 单位
    @TableField(value="department_name")
    private String departmentName; // 单位名称
    
    
    @TableField(exist=false)
    @SubEntity(serviceName="yearTechnologyIndexPlanZiService",pidName = "zhuId")
    private List<YearTechnologyIndexPlanZiEntity> yearTechnologyIndexPlanZiList = new ArrayList<>(); // 年度科技指标计划子表
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getYear() {
        return year;
    }

    public void setYear(String year) {
        this.year = year;
    }

    public Long getDepartmentId() {
        return departmentId;
    }

    public void setDepartmentId(Long departmentId) {
        this.departmentId = departmentId;
    }
    public String getDepartmentName() {
        return departmentName;
    }

    public void setDepartmentName(String departmentName) {
        this.departmentName = departmentName;
    }
    

    public List<YearTechnologyIndexPlanZiEntity> getYearTechnologyIndexPlanZiList() {
        return yearTechnologyIndexPlanZiList;
    }

    public void setYearTechnologyIndexPlanZiList(List<YearTechnologyIndexPlanZiEntity> yearTechnologyIndexPlanZiList) {
        this.yearTechnologyIndexPlanZiList = yearTechnologyIndexPlanZiList;
    }
}
